# Scanners

::: harborapi.client.HarborAsyncClient
    options:
        members:
        - get_scanner
        - create_scanner
        - update_scanner
        - delete_scanner
        - get_scanners
        - set_default_scanner
        - ping_scanner_adapter
